@@ -3,7 +3,6 @@ var assert = require('assert');
 var connect = require('..');
 var http = require('http');
 var request = require('supertest');
-var should = require('should');
 
 describe('app', function(){
   var app;
@@ -17,6 +16,81 @@ describe('app', function(){
     app.emit('foo');
   });
 
+  it('should work in http.createServer', function(done){
+    var app = connect();
+
+    app.use(function (req, res) {
+      res.end('hello, world!');
+    });
+
+    var server = http.createServer(app);
+
+    request(server)
+    .get('/')
+    .expect(200, 'hello, world!', done);
+  })
+
+  it('should be a callable function', function(done){
+    var app = connect();
+
+    app.use(function (req, res) {
+      res.end('hello, world!');
+    });
+
+    function handler(req, res) {
+      res.write('oh, ');
+      app(req, res);
+    }
+
+    var server = http.createServer(handler);
+
+    request(server)
+    .get('/')
+    .expect(200, 'oh, hello, world!', done);
+  })
+
+  it('should invoke callback if request not handled', function(done){
+    var app = connect();
+
+    app.use('/foo', function (req, res) {
+      res.end('hello, world!');
+    });
+
+    function handler(req, res) {
+      res.write('oh, ');
+      app(req, res, function() {
+        res.end('no!');
+      });
+    }
+
+    var server = http.createServer(handler);
+
+    request(server)
+    .get('/')
+    .expect(200, 'oh, no!', done);
+  })
+
+  it('should invoke callback on error', function(done){
+    var app = connect();
+
+    app.use(function (req, res) {
+      throw new Error('boom!');
+    });
+
+    function handler(req, res) {
+      res.write('oh, ');
+      app(req, res, function(err) {
+        res.end(err.message);
+      });
+    }
+
+    var server = http.createServer(handler);
+
+    request(server)
+    .get('/')
+    .expect(200, 'oh, boom!', done);
+  })
+
   it('should work as middleware', function(done){
     // custom server handler array
     var handlers = [connect(), function(req, res, next){
@@ -35,22 +109,11 @@ describe('app', function(){
     }
 
     // create a non-connect server
-    var server = http.createServer(run).listen(5556, function(){
-      http.get({
-        host: 'localhost',
-        port: 5556,
-        path: '/'
-      }, function(res){
-        var buf = '';
-        res.setEncoding('utf8');
-        res.on('data', function(s){ buf += s });
-        res.on('end', function(){
-          buf.should.eql('Ok');
-          server.close();
-          done();
-        });
-      });
-    });
+    var server = http.createServer(run);
+
+    request(server)
+    .get('/')
+    .expect(200, 'Ok', done);
   });
 
   it('should escape the 500 response body', function(done){
@@ -171,7 +234,7 @@ function rawrequest(app) {
   function expect(status, body, callback) {
     server.listen(function(){
       var addr = this.address();
-      var hostname = addr.family === 'IPv6' ? '[::1]' : '127.0.0.1';
+      var hostname = addr.family === 'IPv6' ? '::1' : '127.0.0.1';
       var port = addr.port;
 
       var req = http.get({
